@@ -150,11 +150,11 @@ class NeonatalApgar(ModelSQL, ModelView):
         'apgar_grimace', 'apgar_pulse', 'apgar_appearance'])
 
     def on_change_with_apgar_score(self, vals):
-        apgar_appearance = vals.get('apgar_appearance')
-        apgar_pulse = vals.get('apgar_pulse')
-        apgar_grimace = vals.get('apgar_grimace')
-        apgar_activity = vals.get('apgar_activity')
-        apgar_respiration = vals.get('apgar_respiration')
+        apgar_appearance = vals.get('apgar_appearance') or '0'
+        apgar_pulse = vals.get('apgar_pulse') or '0'
+        apgar_grimace = vals.get('apgar_grimace') or '0'
+        apgar_activity = vals.get('apgar_activity') or '0'
+        apgar_respiration = vals.get('apgar_respiration') or '0'
 
         apgar_score = int(apgar_appearance) + int(apgar_pulse) + \
             int(apgar_grimace) + int(apgar_activity) + int(apgar_respiration)
@@ -188,7 +188,8 @@ class PediatricSymptomsChecklist(ModelSQL, ModelView):
     'Pediatric Symptoms Checklist'
     _name = 'gnuhealth.patient.psc'
     _description = __doc__
-
+    
+    
     patient = fields.Many2One('gnuhealth.patient', 'Patient', required=True)
 
     evaluation_date = fields.Many2One('gnuhealth.appointment', 'Appointment',
@@ -205,212 +206,212 @@ class PediatricSymptomsChecklist(ModelSQL, ModelView):
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Complains of aches and pains')
+        ], 'Complains of aches and pains', sort=False)
 
     psc_spend_time_alone = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Spends more time alone')
+        ], 'Spends more time alone', sort=False)
 
     psc_tires_easily = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Tires easily, has little energy')
+        ], 'Tires easily, has little energy', sort=False)
 
     psc_fidgety = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Fidgety, unable to sit still')
+        ], 'Fidgety, unable to sit still', sort=False)
 
     psc_trouble_with_teacher = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Has trouble with teacher')
+        ], 'Has trouble with teacher', sort=False)
 
     psc_less_interest_in_school = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Less interested in school')
+        ], 'Less interested in school', sort=False)
 
     psc_acts_as_driven_by_motor = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Acts as if driven by a motor')
+        ], 'Acts as if driven by a motor', sort=False)
 
     psc_daydreams_too_much = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Daydreams too much')
+        ], 'Daydreams too much', sort=False)
 
     psc_distracted_easily = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Distracted easily')
+        ], 'Distracted easily', sort=False)
 
     psc_afraid_of_new_situations = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Is afraid of new situations')
+        ], 'Is afraid of new situations', sort=False)
 
     psc_sad_unhappy = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Feels sad, unhappy')
+        ], 'Feels sad, unhappy', sort=False)
 
     psc_irritable_angry = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Is irritable, angry')
+        ], 'Is irritable, angry', sort=False)
 
     psc_feels_hopeless = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Feels hopeless')
+        ], 'Feels hopeless', sort=False)
 
     psc_trouble_concentrating = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Has trouble concentrating')
+        ], 'Has trouble concentrating', sort=False)
 
     psc_less_interested_in_friends = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Less interested in friends')
+        ], 'Less interested in friends', sort=False)
 
     psc_fights_with_others = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Fights with other children')
+        ], 'Fights with other children', sort=False)
 
     psc_absent_from_school = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Absent from school')
+        ], 'Absent from school', sort=False)
 
     psc_school_grades_dropping = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'School grades dropping')
+        ], 'School grades dropping', sort=False)
 
     psc_down_on_self = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Is down on him or herself')
+        ], 'Is down on him or herself', sort=False)
 
     psc_visit_doctor_finds_ok = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Visits the doctor with doctor finding nothing wrong')
+        ], 'Visits the doctor with doctor finding nothing wrong', sort=False)
 
     psc_trouble_sleeping = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Has trouble sleeping')
+        ], 'Has trouble sleeping', sort=False)
 
     psc_worries_a_lot = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Worries a lot')
+        ], 'Worries a lot', sort=False)
 
     psc_wants_to_be_with_parents = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Wants to be with you more than before')
+        ], 'Wants to be with you more than before', sort=False)
 
     psc_feels_is_bad_child = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Feels he or she is bad')
+        ], 'Feels he or she is bad', sort=False)
 
     psc_takes_unnecesary_risks = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Takes unnecessary risks')
+        ], 'Takes unnecessary risks', sort=False)
 
     psc_gets_hurt_often = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Gets hurt frequently')
+        ], 'Gets hurt frequently', sort=False)
 
     psc_having_less_fun = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Seems to be having less fun')
+        ], 'Seems to be having less fun', sort=False)
 
     psc_act_as_younger = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Acts younger than children his or her age')
+        ], 'Acts younger than children his or her age', sort=False)
 
     psc_does_not_listen_to_rules = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Does not listen to rules')
+        ], 'Does not listen to rules', sort=False)
 
     psc_does_not_show_feelings = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Does not show feelings')
+        ], 'Does not show feelings', sort=False)
 
 
     psc_does_not_get_people_feelings = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Does not get people feelings')
+        ], 'Does not get people feelings', sort=False)
 
     psc_teases_others = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Teases others')
+        ], 'Teases others', sort=False)
 
     psc_blames_others = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Blames others for his or her troubles')
+        ], 'Blames others for his or her troubles', sort=False)
 
     psc_takes_things_from_others = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Takes things that do not belong to him or her')
+        ], 'Takes things that do not belong to him or her', sort=False)
 
     psc_refuses_to_share = fields.Selection([
         ('0', 'Never'),
         ('1', 'Sometimes'),
         ('2', 'Often'),
-        ], 'Refuses to share')
+        ], 'Refuses to share', sort=False)
 
     psc_total = fields.Integer('PSC Total',
         on_change_with=['psc_aches_pains', 'psc_spend_time_alone',
@@ -439,42 +440,42 @@ class PediatricSymptomsChecklist(ModelSQL, ModelView):
 
     def on_change_with_psc_total(self, vals):
 
-        psc_aches_pains = vals.get('psc_aches_pains')
-        psc_spend_time_alone = vals.get('psc_spend_time_alone')
-        psc_tires_easily = vals.get('psc_tires_easily')
-        psc_fidgety = vals.get('psc_fidgety')
-        psc_trouble_with_teacher = vals.get('psc_trouble_with_teacher')
-        psc_less_interest_in_school = vals.get('psc_less_interest_in_school')
-        psc_acts_as_driven_by_motor = vals.get('psc_acts_as_driven_by_motor')
-        psc_daydreams_too_much = vals.get('psc_daydreams_too_much')
-        psc_distracted_easily = vals.get('psc_distracted_easily')
-        psc_afraid_of_new_situations = vals.get('psc_afraid_of_new_situations')
-        psc_sad_unhappy = vals.get('psc_sad_unhappy')
-        psc_irritable_angry = vals.get('psc_irritable_angry')
-        psc_feels_hopeless = vals.get('psc_feels_hopeless')
-        psc_trouble_concentrating = vals.get('psc_trouble_concentrating')
+        psc_aches_pains = vals.get('psc_aches_pains') or '0'
+        psc_spend_time_alone = vals.get('psc_spend_time_alone') or '0'
+        psc_tires_easily = vals.get('psc_tires_easily') or '0'
+        psc_fidgety = vals.get('psc_fidgety') or '0'
+        psc_trouble_with_teacher = vals.get('psc_trouble_with_teacher') or '0'
+        psc_less_interest_in_school = vals.get('psc_less_interest_in_school') or '0'
+        psc_acts_as_driven_by_motor = vals.get('psc_acts_as_driven_by_motor') or '0'
+        psc_daydreams_too_much = vals.get('psc_daydreams_too_much') or '0'
+        psc_distracted_easily = vals.get('psc_distracted_easily') or '0'
+        psc_afraid_of_new_situations = vals.get('psc_afraid_of_new_situations') or '0'
+        psc_sad_unhappy = vals.get('psc_sad_unhappy') or '0'
+        psc_irritable_angry = vals.get('psc_irritable_angry') or '0'
+        psc_feels_hopeless = vals.get('psc_feels_hopeless') or '0'
+        psc_trouble_concentrating = vals.get('psc_trouble_concentrating') or '0'
         psc_less_interested_in_friends = \
-                vals.get('psc_less_interested_in_friends')
-        psc_fights_with_others = vals.get('psc_fights_with_others')
-        psc_absent_from_school = vals.get('psc_absent_from_school')
-        psc_school_grades_dropping = vals.get('psc_school_grades_dropping')
-        psc_down_on_self = vals.get('psc_down_on_self')
-        psc_visit_doctor_finds_ok = vals.get('psc_visit_doctor_finds_ok')
-        psc_trouble_sleeping = vals.get('psc_trouble_sleeping')
-        psc_worries_a_lot = vals.get('psc_worries_a_lot')
-        psc_wants_to_be_with_parents = vals.get('psc_wants_to_be_with_parents')
-        psc_feels_is_bad_child = vals.get('psc_feels_is_bad_child')
-        psc_takes_unnecesary_risks = vals.get('psc_takes_unnecesary_risks')
-        psc_gets_hurt_often = vals.get('psc_gets_hurt_often')
-        psc_having_less_fun = vals.get('psc_having_less_fun')
-        psc_act_as_younger = vals.get('psc_act_as_younger')
-        psc_does_not_listen_to_rules = vals.get('psc_does_not_listen_to_rules')
-        psc_does_not_show_feelings = vals.get('psc_does_not_show_feelings')
+                vals.get('psc_less_interested_in_friends') or '0'
+        psc_fights_with_others = vals.get('psc_fights_with_others') or '0'
+        psc_absent_from_school = vals.get('psc_absent_from_school') or '0'
+        psc_school_grades_dropping = vals.get('psc_school_grades_dropping') or '0'
+        psc_down_on_self = vals.get('psc_down_on_self') or '0'
+        psc_visit_doctor_finds_ok = vals.get('psc_visit_doctor_finds_ok') or '0'
+        psc_trouble_sleeping = vals.get('psc_trouble_sleeping') or '0'
+        psc_worries_a_lot = vals.get('psc_worries_a_lot') or '0'
+        psc_wants_to_be_with_parents = vals.get('psc_wants_to_be_with_parents') or '0'
+        psc_feels_is_bad_child = vals.get('psc_feels_is_bad_child') or '0'
+        psc_takes_unnecesary_risks = vals.get('psc_takes_unnecesary_risks') or '0'
+        psc_gets_hurt_often = vals.get('psc_gets_hurt_often') or '0'
+        psc_having_less_fun = vals.get('psc_having_less_fun') or '0'
+        psc_act_as_younger = vals.get('psc_act_as_younger') or '0'
+        psc_does_not_listen_to_rules = vals.get('psc_does_not_listen_to_rules') or '0'
+        psc_does_not_show_feelings = vals.get('psc_does_not_show_feelings') or '0'
         psc_does_not_get_people_feelings = \
-                vals.get('psc_does_not_get_people_feelings')
-        psc_teases_others = vals.get('psc_teases_others')
-        psc_takes_things_from_others = vals.get('psc_takes_things_from_others')
-        psc_refuses_to_share = vals.get('psc_refuses_to_share')
+                vals.get('psc_does_not_get_people_feelings') or '0'
+        psc_teases_others = vals.get('psc_teases_others') or '0'
+        psc_takes_things_from_others = vals.get('psc_takes_things_from_others') or '0'
+        psc_refuses_to_share = vals.get('psc_refuses_to_share') or '0'
 
         psc_total = int(psc_aches_pains) + int(psc_spend_time_alone) + \
             int(psc_tires_easily) + int(psc_fidgety) + \
@@ -504,13 +505,17 @@ class PediatricSymptomsChecklist(ModelSQL, ModelView):
 PediatricSymptomsChecklist()
 
 
+# REMOVED IN 1.6
+# WE USE A RELATE ACTION
 
+'''
 class PscEvaluation(ModelSQL, ModelView):
     'Pediatric Symptoms Checklist Evaluation'
     _name = 'gnuhealth.patient'
     _description = __doc__
 
-    psc = fields.One2Many('gnuhealth.patient.psc', 'name',
+    psc = fields.One2Many('gnuhealth.patient.psc', 'patient',
         'Pediatric Symptoms Checklist')
 
 PscEvaluation()
+'''
