@@ -22,7 +22,6 @@ from trytond.model import ModelView, ModelSQL, fields
 
 
 class MedicalPatient(ModelSQL, ModelView):
-    'Socioeconomics. Inherits Medical Patient and adds new fields to model'
     _name = 'gnuhealth.patient'
     _description = __doc__
 
@@ -160,10 +159,10 @@ class MedicalPatient(ModelSQL, ModelView):
 
     def on_change_with_fam_apgar_score(self, vals):
         fam_apgar_help = int(vals.get('fam_apgar_help'))
-        fam_apgar_timesharing = int(vals.get('fam_apgar_timesharing'))
-        fam_apgar_discussion = int(vals.get('fam_apgar_discussion'))
-        fam_apgar_decisions = int(vals.get('fam_apgar_decisions'))
-        fam_apgar_affection = int(vals.get('fam_apgar_affection'))
+        fam_apgar_timesharing = int(vals.get('fam_apgar_timesharing') or '0')
+        fam_apgar_discussion = int(vals.get('fam_apgar_discussion') or '0')
+        fam_apgar_decisions = int(vals.get('fam_apgar_decisions') or '0')
+        fam_apgar_affection = int(vals.get('fam_apgar_affection') or '0')
         total = (fam_apgar_help + fam_apgar_timesharing +
             fam_apgar_discussion + fam_apgar_decisions +
             fam_apgar_affection)
